@@ -43,6 +43,16 @@
 #include <sys/uio.h>
 #include "kcapi_aio.h"
 
+#define MAJVERSION 0  /* API / ABI incompatible changes, functional changes that
+		       * require consumer to be updated (as long as this number
+		       * is zero, the API is not considered stable and can
+		       * change without a bump of the major version) */
+#define MINVERSION 11 /* API compatible, ABI may change, functional
+		       * enhancements only, consumer can be left unchanged if
+		       * enhancements are not considered */
+#define PATCHLEVEL 1  /* API / ABI compatible, no functional changes, no
+		       * enhancements, bug fixes only */
+
 #if __GNUC__ >= 4
 # define DSO_PUBLIC __attribute__ ((visibility ("default")))
 #else
@@ -198,7 +208,7 @@ int32_t kcapi_cipher_decrypt(struct kcapi_handle *handle,
  *
  * @handle: [in] cipher handle
  * @iv: [in] IV to be used for cipher operation
- * @iov: [out] scatter/gather list with data to be encrypted. This is
+ * @iov: [in] scatter/gather list with data to be encrypted. This is
  *	the pointer to the first iov entry if an array of iov
  *	entries is supplied. See sendmsg(2) for details on how iov is
  *	to be used. This pointer may be NULL if no data to be encrypted
@@ -231,7 +241,7 @@ int32_t kcapi_cipher_stream_init_enc(struct kcapi_handle *handle,
  *
  * @handle: [in] cipher handle
  * @iv: [in] IV to be used for cipher operation
- * @iov: [out] scatter/gather list with data to be encrypted. This is
+ * @iov: [in] scatter/gather list with data to be encrypted. This is
  *	the pointer to the first iov entry if an array of iov
  *	entries is supplied. See sendmsg(2) for details on how iov is
  *	to be used. This pointer may be NULL if no data to be encrypted
@@ -264,7 +274,7 @@ int32_t kcapi_cipher_stream_init_dec(struct kcapi_handle *handle,
  * kcapi_cipher_stream_update() - send more data for processing (stream)
  *
  * @handle: [in] cipher handle
- * @iov: [in/out] scatter/gather list with data to be processed by the
+ * @iov: [in] scatter/gather list with data to be processed by the
  *	cipher operation.
  * @iovlen: [in] number of scatter/gather list elements.
  *
@@ -300,7 +310,7 @@ int32_t kcapi_cipher_stream_update(struct kcapi_handle *handle,
  * kcapi_cipher_stream_op() - obtain processed data (stream)
  *
  * @handle: [in] cipher handle
- * @iov: [in/out] scatter/gather list pointing to buffers to be filled with
+ * @iov: [out] scatter/gather list pointing to buffers to be filled with
  *	the resulting data from a cipher operation.
  * @iovlen: [in] number of scatter/gather list elements.
  *
